"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SdGenerationStyle(str, Enum):
    r"""The style to generate images with. When photoReal is enabled, refer to the Guide section for a full list. When alchemy is disabled, use LEONARDO or NONE. When alchemy is enabled, use ANIME, CREATIVE, DYNAMIC, ENVIRONMENT, GENERAL, ILLUSTRATION, PHOTOGRAPHY, RAYTRACED, RENDER_3D, SKETCH_BW, SKETCH_COLOR, or NONE."""
    ANIME = 'ANIME'
    BOKEH = 'BOKEH'
    CINEMATIC = 'CINEMATIC'
    CINEMATIC_CLOSEUP = 'CINEMATIC_CLOSEUP'
    CREATIVE = 'CREATIVE'
    DYNAMIC = 'DYNAMIC'
    ENVIRONMENT = 'ENVIRONMENT'
    FASHION = 'FASHION'
    FILM = 'FILM'
    FOOD = 'FOOD'
    GENERAL = 'GENERAL'
    HDR = 'HDR'
    ILLUSTRATION = 'ILLUSTRATION'
    LEONARDO = 'LEONARDO'
    LONG_EXPOSURE = 'LONG_EXPOSURE'
    MACRO = 'MACRO'
    MINIMALISTIC = 'MINIMALISTIC'
    MONOCHROME = 'MONOCHROME'
    MOODY = 'MOODY'
    NONE = 'NONE'
    NEUTRAL = 'NEUTRAL'
    PHOTOGRAPHY = 'PHOTOGRAPHY'
    PORTRAIT = 'PORTRAIT'
    RAYTRACED = 'RAYTRACED'
    RENDER_3_D = 'RENDER_3D'
    RETRO = 'RETRO'
    SKETCH_BW = 'SKETCH_BW'
    SKETCH_COLOR = 'SKETCH_COLOR'
    STOCK_PHOTO = 'STOCK_PHOTO'
    VIBRANT = 'VIBRANT'
    UNPROCESSED = 'UNPROCESSED'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PricingCalculatorServices(str, Enum):
    r"""The services to be chosen for calculating the API credit cost."""
    IMAGE_GENERATION = 'IMAGE_GENERATION'
    FANTASY_AVATAR_GENERATION = 'FANTASY_AVATAR_GENERATION'
    MOTION_GENERATION = 'MOTION_GENERATION'
    LCM_GENERATION = 'LCM_GENERATION'
    MODEL_TRAINING = 'MODEL_TRAINING'
    TEXTURE_GENERATION = 'TEXTURE_GENERATION'
    UNIVERSAL_UPSCALER = 'UNIVERSAL_UPSCALER'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from .dataset import Dataset
from .element import Element
from .generation import Generation
from .initimage import InitImage
from .model import Model
from .pricing_calculator import PricingCalculator
from .prompt import Prompt
from .sdkconfiguration import SDKConfiguration
from .user import User
from .utils.retries import RetryConfig
from .variation import Variation
from leonardoaisdk import utils
from leonardoaisdk._hooks import SDKHooks
from leonardoaisdk.models import shared
from typing import Callable, Dict, Optional, Union

class LeonardoAiSDK:
    r"""Rest Endpoints: Leonardo.Ai API OpenAPI specification."""
    dataset: Dataset
    element: Element
    generation: Generation
    init_image: InitImage
    user: User
    model: Model
    pricing_calculator: PricingCalculator
    prompt: Prompt
    variation: Variation

    sdk_configuration: SDKConfiguration

    def __init__(self,
                 bearer_auth: Union[str, Callable[[], str]],
                 server_idx: Optional[int] = None,
                 server_url: Optional[str] = None,
                 url_params: Optional[Dict[str, str]] = None,
                 client: Optional[requests_http.Session] = None,
                 retry_config: Optional[RetryConfig] = None
                 ) -> None:
        """Instantiates the SDK configuring it with the provided parameters.

        :param bearer_auth: The bearer_auth required for authentication
        :type bearer_auth: Union[str, Callable[[], str]]
        :param server_idx: The index of the server to use for all operations
        :type server_idx: int
        :param server_url: The server URL to use for all operations
        :type server_url: str
        :param url_params: Parameters to optionally template the server URL with
        :type url_params: Dict[str, str]
        :param client: The requests.Session HTTP client to use for all operations
        :type client: requests_http.Session
        :param retry_config: The utils.RetryConfig to use globally
        :type retry_config: RetryConfig
        """
        if client is None:
            client = requests_http.Session()

        if callable(bearer_auth):
            def security():
                return shared.Security(bearer_auth = bearer_auth())
        else:
            security = shared.Security(bearer_auth = bearer_auth)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)
    

        self.sdk_configuration = SDKConfiguration(
            client,
            security,
            server_url,
            server_idx,
            retry_config=retry_config
        )

        hooks = SDKHooks()

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(current_server_url, self.sdk_configuration.client)
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__['_hooks'] = hooks

        self._init_sdks()


    def _init_sdks(self):
        self.dataset = Dataset(self.sdk_configuration)
        self.element = Element(self.sdk_configuration)
        self.generation = Generation(self.sdk_configuration)
        self.init_image = InitImage(self.sdk_configuration)
        self.user = User(self.sdk_configuration)
        self.model = Model(self.sdk_configuration)
        self.pricing_calculator = PricingCalculator(self.sdk_configuration)
        self.prompt = Prompt(self.sdk_configuration)
        self.variation = Variation(self.sdk_configuration)



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ModelAssetTextureTypes(str, Enum):
    r"""When training model assets these are the texture types available to use."""
    ALBEDO = 'ALBEDO'
    NORMAL = 'NORMAL'
    ROUGHNESS = 'ROUGHNESS'
    DISPLACEMENT = 'DISPLACEMENT'
    HDRP_MASK = 'HDRP_MASK'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ...models.shared import pricingcalculatorservices as shared_pricingcalculatorservices
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PricingCalculatorObject:
    r"""Parameters for FANTASY_AVATAR_GENERATION service"""
    image_height: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('imageHeight'), 'exclude': lambda f: f is None }})
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""
    image_width: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('imageWidth'), 'exclude': lambda f: f is None }})
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""
    num_images: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('numImages'), 'exclude': lambda f: f is None }})
    r"""The number of images to generate. Must be between 1 and 8. If either width or height is over 768, must be between 1 and 4."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PricingCalculatorPricingCalculatorObject:
    r"""Parameters for IMAGE_GENERATION service"""
    UNSET='__SPEAKEASY_UNSET__'
    alchemy_mode: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('alchemyMode'), 'exclude': lambda f: f is None }})
    r"""Enable to use Alchemy."""
    controlnets_cost: Optional[int] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('controlnetsCost'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorObject.UNSET }})
    r"""The total cost of controlnets input."""
    high_resolution: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('highResolution'), 'exclude': lambda f: f is None }})
    r"""Enable to use high resolution."""
    image_height: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('imageHeight'), 'exclude': lambda f: f is None }})
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""
    image_width: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('imageWidth'), 'exclude': lambda f: f is None }})
    r"""The input height of the images. Must be between 32 and 1024 and be a multiple of 8. Note: Input resolution is not always the same as output resolution due to upscaling from other features"""
    inference_steps: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('inferenceSteps'), 'exclude': lambda f: f is None }})
    r"""The Step Count to use for the generation. Must be between 10 and 60."""
    is_model_custom: Optional[bool] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('isModelCustom'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorObject.UNSET }})
    r"""Enable to use custom model."""
    is_sdxl: Optional[bool] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('isSDXL'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorObject.UNSET }})
    r"""Enable to use SDXL model."""
    is_sdxl_lightning: Optional[bool] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('isSDXLLightning'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorObject.UNSET }})
    r"""Enable to use SDXL Lightning model."""
    lora_count: Optional[int] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('loraCount'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorObject.UNSET }})
    r"""The number of elements used for the generation."""
    num_images: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('numImages'), 'exclude': lambda f: f is None }})
    r"""The number of images to generate. Must be between 1 and 8. If either width or height is over 768, must be between 1 and 4."""
    prompt_magic: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('promptMagic'), 'exclude': lambda f: f is None }})
    r"""Enable to use prompt magic."""
    prompt_magic_strength: Optional[float] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('promptMagicStrength'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorObject.UNSET }})
    r"""Strength of prompt magic. Must be a float between 0.1 and 1.0"""
    prompt_magic_strength_arg: Optional[int] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('promptMagicStrengthArg'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorObject.UNSET }})
    r"""Strength of prompt magic."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PricingCalculatorPricingCalculatorRequestObject:
    r"""Parameters for LCM_GENERATION service"""
    UNSET='__SPEAKEASY_UNSET__'
    height: Optional[int] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('height'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorRequestObject.UNSET }})
    r"""The output height of the image. Must be 512, 640 or 1024."""
    instant_refine: Optional[bool] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('instantRefine'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorRequestObject.UNSET }})
    r"""Enable for instant upscale"""
    refine: Optional[bool] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('refine'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorRequestObject.UNSET }})
    r"""Enable for normal alchemy upscale"""
    width: Optional[int] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('width'), 'exclude': lambda f: f is PricingCalculatorPricingCalculatorRequestObject.UNSET }})
    r"""The output width of the image. Must be 512, 640 or 1024."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PricingCalculatorPricingCalculatorRequestRequestBodyObject:
    r"""Parameters for MODEL_TRAINING service"""
    resolution: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('resolution'), 'exclude': lambda f: f is None }})
    r"""The resolution for training. Must be 512 or 768."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObject:
    r"""Parameters for MOTION_GENERATION service"""
    duration_seconds: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('durationSeconds'), 'exclude': lambda f: f is None }})
    r"""The total duration of the motion generation in seconds."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObject:
    r"""Parameters for TEXTURE_GENERATION service"""
    preview: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('preview'), 'exclude': lambda f: f is None }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObject:
    r"""Parameters for UNIVERSAL_UPSCALER service"""
    megapixel: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('megapixel'), 'exclude': lambda f: f is None }})
    r"""The maximum upscaled image size is 20 megapixels."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Object:
    r"""Parameters for the service"""
    UNSET='__SPEAKEASY_UNSET__'
    fantasy_avatar_generation: Optional[PricingCalculatorObject] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('FANTASY_AVATAR_GENERATION'), 'exclude': lambda f: f is Object.UNSET }})
    r"""Parameters for FANTASY_AVATAR_GENERATION service"""
    image_generation: Optional[PricingCalculatorPricingCalculatorObject] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('IMAGE_GENERATION'), 'exclude': lambda f: f is Object.UNSET }})
    r"""Parameters for IMAGE_GENERATION service"""
    lcm_generation: Optional[PricingCalculatorPricingCalculatorRequestObject] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('LCM_GENERATION'), 'exclude': lambda f: f is Object.UNSET }})
    r"""Parameters for LCM_GENERATION service"""
    model_training: Optional[PricingCalculatorPricingCalculatorRequestRequestBodyObject] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('MODEL_TRAINING'), 'exclude': lambda f: f is Object.UNSET }})
    r"""Parameters for MODEL_TRAINING service"""
    motion_generation: Optional[PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObject] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('MOTION_GENERATION'), 'exclude': lambda f: f is Object.UNSET }})
    r"""Parameters for MOTION_GENERATION service"""
    texture_generation: Optional[PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObject] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('TEXTURE_GENERATION'), 'exclude': lambda f: f is Object.UNSET }})
    r"""Parameters for TEXTURE_GENERATION service"""
    universal_upscaler: Optional[PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObject] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('UNIVERSAL_UPSCALER'), 'exclude': lambda f: f is Object.UNSET }})
    r"""Parameters for UNIVERSAL_UPSCALER service"""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PricingCalculatorRequestBody:
    service: Optional[shared_pricingcalculatorservices.PricingCalculatorServices] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('service'), 'exclude': lambda f: f is None }})
    r"""The services to be chosen for calculating the API credit cost."""
    service_params: Optional[Object] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('serviceParams'), 'exclude': lambda f: f is None }})
    r"""Parameters for the service"""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CalculateProductionAPIServiceCost:
    cost: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('cost'), 'exclude': lambda f: f is None }})
    r"""API service cost to generate the image."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PricingCalculatorResponseBody:
    r"""Responses for POST /pricing-calculator"""
    UNSET='__SPEAKEASY_UNSET__'
    calculate_production_api_service_cost: Optional[CalculateProductionAPIServiceCost] = dataclasses.field(default=UNSET, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('calculateProductionApiServiceCost'), 'exclude': lambda f: f is PricingCalculatorResponseBody.UNSET }})
    



@dataclasses.dataclass
class PricingCalculatorResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: Optional[PricingCalculatorResponseBody] = dataclasses.field(default=None)
    r"""Responses for POST /pricing-calculator"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomModelType(str, Enum):
    r"""The category the most accurately reflects the model."""
    GENERAL = 'GENERAL'
    BUILDINGS = 'BUILDINGS'
    CHARACTERS = 'CHARACTERS'
    ENVIRONMENTS = 'ENVIRONMENTS'
    FASHION = 'FASHION'
    ILLUSTRATIONS = 'ILLUSTRATIONS'
    GAME_ITEMS = 'GAME_ITEMS'
    GRAPHICAL_ELEMENTS = 'GRAPHICAL_ELEMENTS'
    PHOTOGRAPHY = 'PHOTOGRAPHY'
    PIXEL_ART = 'PIXEL_ART'
    PRODUCT_DESIGN = 'PRODUCT_DESIGN'
    TEXTURES = 'TEXTURES'
    UI_ELEMENTS = 'UI_ELEMENTS'
    VECTOR = 'VECTOR'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import setuptools
import re

try:
    with open('README.md', 'r') as fh:
        long_description = fh.read()
        GITHUB_URL = 'https://github.com/Leonardo-Interactive/leonardo-python-sdk.git'
        GITHUB_URL = GITHUB_URL[: -len('.git')] if GITHUB_URL.endswith('.git') else GITHUB_URL
        # links on PyPI should have absolute URLs
        long_description = re.sub(
            r'(\[[^\]]+\]\()((?!https?:)[^\)]+)(\))',
            lambda m: m.group(1) + GITHUB_URL + '/blob/master/' + m.group(2) + m.group(3),
            long_description,
        )
except FileNotFoundError:
    long_description = ''

setuptools.setup(
    name='Leonardo-Ai-SDK',
    version='5.4.2',
    author='Leonardo-Ai',
    description='Leonardo AI Python Client SDK',
    url='https://github.com/Leonardo-Interactive/leonardo-python-sdk.git',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(where='src'),
    install_requires=[
        "certifi>=2023.7.22",
        "charset-normalizer>=3.2.0",
        "dataclasses-json>=0.6.4",
        "idna>=3.4",
        "jsonpath-python>=1.0.6",
        "marshmallow>=3.19.0",
        "mypy-extensions>=1.0.0",
        "packaging>=23.1",
        "python-dateutil>=2.8.2",
        "requests>=2.31.0",
        "six>=1.16.0",
        "typing-inspect>=0.9.0",
        "typing_extensions>=4.7.1",
        "urllib3>=1.26.18",
    ],
    extras_require={
        "dev": [
            "pylint==3.1.0",
        ],
    },
    package_dir={'': 'src'},
    python_requires='>=3.8',
    package_data={
        'Leonardo-Ai-SDK': ['py.typed']
    },
)
